@@ -250,7 +250,7 @@ enum gfm_proto_command {
 	GFM_PROTO_REPLICATION_CKSUM_RESULT,	/* since gfarm-2.6.0 */
 	GFM_PROTO_REPLICA_ADDING_CKSUM,		/* since gfarm-2.6.0 */
 	GFM_PROTO_REPLICA_ADDED_CKSUM,		/* since gfarm-2.6.0 */
-	GFM_PROTO_REPLICA_MNG_RESERVE12,
+	GFM_PROTO_REPLICA_OPEN_STATUS,		/* since gfarm-2.6.6 */
 	GFM_PROTO_REPLICA_MNG_RESERVE13,
 	GFM_PROTO_REPLICA_MNG_RESERVE14,
 	GFM_PROTO_REPLICA_MNG_RESERVE15,
@@ -375,6 +375,12 @@ enum gfm_proto_command {
  */
 #define	GFM_PROTO_CKSUM_SET_REPORT_ONLY		0x00000001 /* since 2.6.1 */
 
+/*
+ * GFM_PROTO_REPLICA_OPEN_STATUS result flags
+ */
+#define	GFM_PROTO_REPLICA_OPENED_WRITE		0x00000001
+#define	GFM_PROTO_REPLICA_OPENED_READ		0x00000002
+
 /*
  * GFM_PROTO_REPLICA_ADDING_CKSUM request flags:
  * just same with both GFS_PROTO_REPLICATION_CKSUM_REQUEST flags
